[−][src]Enum cortex_mpu::cortex_m0p::Size
Size of a memory region.
The Cortex-M MPUs only support this very limited number of size classes, and do not allow configuring an arbitrary memory region size.
Variants
S256B256 Bytes.
S1K1 KiB (1024 Bytes).
S1M1 MiB (1024 KiB, 1048576 Bytes).
S1G1 GiB.
S4G4 GiB (covering the entire memory space).