[−][src]Struct cortex_mpu::cortex_m0p::Region
Memory region properties.
Fields
base_addr: usizeStarting address of the region (lowest address).
This must be aligned to the region's size.
size: SizeSize of the region.
subregions: SubregionsThe subregions to enable or disable.
executable: boolWhether to allow instruction fetches from this region.
If this is false, the region will be marked as NX (Never eXecute).
This affects both privileged and unprivileged code, regardless of
other MPU settings.
permissions: AccessPermissionData access permissions for the region.
attributes: MemoryAttributesMemory type and cache policy attributes.