[−][src]Enum cortex_mpu::cortex_m4::MemoryAttributes
Describes memory type, cache policy, and shareability.
Variants
StronglyOrderedShareable, non-cached, strongly-ordered memory region.
DeviceNon-cached device peripheral region.
Fields of Device
Whether the region is accessible by more than one bus master (eg. a DMA engine or a second MCU core).
NormalNormal memory region (ie. "actual" memory, such as Flash or SRAM).
Fields of Normal
Whether the region is accessible by more than one bus master (eg. a DMA engine or a second MCU core).
cache_policy: CachePolicyHow this region should be cached (?).